@@ -9,15 +9,25 @@ from trytond.pyson import Eval
 class Template(metaclass=PoolMeta):
     __name__ = 'product.template'
 
-    lot_unit = fields.Many2One('product.uom', "Lot Unit",
+    lot_uom = fields.Many2One('product.uom', "Lot UoM",
         domain=[
             ('category', '=', Eval('default_uom_category', -1)),
             ],
         states={
             'invisible': Eval('type') == 'service',
             },
-        depends=['type', 'default_uom_category'],
-        help="The default unit for lot.")
+        help="The default unit of measurer for lot.")
+
+    @classmethod
+    def __register__(cls, module_name):
+        table_h = cls.__table_handler__(module_name)
+
+        # Migration from 6.8: rename lot_unit to lot_uom
+        if (table_h.column_exist('lot_unit')
+                and not table_h.column_exist('lot_uom')):
+            table_h.column_rename('lot_unit', 'lot_uom')
+
+        super().__register__(module_name)
 
 
 class Product(metaclass=PoolMeta):
